@@ -477,6 +477,34 @@ freebsdFix()
             touch ./needreboot.txt
         fi
     fi
+}
+
+
+fixPagespeed()
+{
+PSOLVERSION=1.11.33.4
+cat << EOF > ../thirdparty/psol-$PSOLVERSION/include/pagespeed/kernel/base/scoped_ptr.h
+/**
+* Due the compiling issue, this file was updated from the original file.
+*/
+#ifndef PAGESPEED_KERNEL_BASE_SCOPED_PTR_H_
+#define PAGESPEED_KERNEL_BASE_SCOPED_PTR_H_
+#include "base/memory/scoped_ptr.h"
+
+namespace net_instaweb {
+template<typename T> class scoped_array : public scoped_ptr<T[]> {
+public:
+    scoped_array() : scoped_ptr<T[]>() {}
+    explicit scoped_array(T* t) : scoped_ptr<T[]>(t) {}
+};
+}
+#endif
+
+EOF
+
+
+
+
 }
 
 cd `dirname "$0"`
@@ -509,8 +537,8 @@ if [ "${ISLINUX}" != "yes" ] ; then
     sed -i -e "s/psol/ /g"  ./build_ols.sh
 fi
 
-./build_ols.sh
 
+./build_ols.sh
 
 cd ${CURDIR}
 
@@ -524,6 +552,10 @@ cp ../thirdparty/src/brotli/out/*.a          ../thirdparty/lib64/
 cp ../thirdparty/src//libxml2/.libs/*.a      ../thirdparty/lib64/
 cp ../thirdparty/src/libmaxminddb/include/*  ../thirdparty/include/
 
+if [ "${ISLINUX}" = "yes" ] ; then
+    fixPagespeed
+fi
+
 #special case modsecurity
 cd src/modules/modsecurity-ls
 ln -sf ../../../../thirdparty/src/ModSecurity .
