@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -23,19 +23,19 @@
 
 #define HEADER_BUF_PAD          4
 #define DEFAULT_HTTP_PORT       80
-#define MAX_BUF_SIZE            16384
+#define MAX_BUF_SIZE            65536
 #define MAX_URL_LEN             MAX_BUF_SIZE
 
 #define THROTTLE_UNIT           4096
-#define MAX_REQ_HEADER_BUF_LEN  (8192*2 - HEADER_BUF_PAD)
+#define MAX_REQ_HEADER_BUF_LEN  (131072 - HEADER_BUF_PAD)
 #define MAX_REQ_BODY_LEN        (LLONG_MAX - 1)
 #define MAX_DYN_RESP_LEN        LLONG_MAX
-#define MAX_DYN_RESP_HEADER_LEN 65536
+#define MAX_DYN_RESP_HEADER_LEN 131072
 
-#define DEFAULT_URL_LEN             8192
-#define DEFAULT_REQ_HEADER_BUF_LEN  16380
+#define DEFAULT_URL_LEN             32768
+#define DEFAULT_REQ_HEADER_BUF_LEN  65536
 #define DEFAULT_REQ_BODY_LEN        (2047 * 1024 * 1024)
-#define DEFAULT_DYN_RESP_HEADER_LEN 16384
+#define DEFAULT_DYN_RESP_HEADER_LEN 65536
 #define DEFAULT_DYN_RESP_LEN        (2047 * 1024 * 1024)
 
 #define DEFAULT_CONN_LOW_MARK   5
